/// Inspects schema
pub mod discover;

/// Generic db insert command
pub mod insert;

/// Connects to db and decides what data will be generated
pub mod spawn;

/// checks if data_types are supported
pub mod data_types;